from com import Component, msgs
import platforms
import values
from theme import theme


class Initialiser(Component):
    """
    Performs initialisation tasks such as setting the theme.
    """

    def __init__(self):

        if (platforms.PLATFORM == platforms.MAEMO5):
            platforms.create_osso_context(values.OSSO_NAME, "1.0", False)

        Component.__init__(self)
        #theme.set_theme("kuro")
        
